@@ -1071,6 +1071,7 @@ C
 C------ laminar wake CD
         CALL DILW( HK2, RT2, DI2L, DI2L_HK2, DI2L_RT2 )
         IF(DI2L .GT. DI2) THEN
+cc        IF(.true.) THEN
 C------- laminar wake CD is greater than turbulent CD -- use laminar
 C-       (this will only occur for unreasonably small Rtheta)
 ccc         write(*,*) 'CDt CDl Rt Hk:', DI2, DI2L, RT2, HK2
@@ -2336,9 +2337,11 @@ C---- Laminar HS correlation
      &       - 0.0278*(3.0*TMP**2 - TMP**3/(HK+1.0))/(HK+1.0)
      &       - 0.0002*2.0*TMP*HK * (TMP + HK)
       ELSE
-       HS    = 0.015*    (HK-4.35)**2/HK + 1.528
-       HS_HK = 0.015*2.0*(HK-4.35)   /HK
-     &       - 0.015*    (HK-4.35)**2/HK**2
+       HS2 = 0.015
+c       HS2 = 0.09
+       HS    = HS2*    (HK-4.35)**2/HK + 1.528
+       HS_HK = HS2*2.0*(HK-4.35)   /HK
+     &       - HS2*    (HK-4.35)**2/HK**2
       ENDIF
 C
       HS_RT  = 0.
